@@ -5,6 +5,6 @@ class RemoteUserMiddleware(MiddlewareMixin):
     def process_request(self, request):
         request.user_id = None
         if user_id := request.headers.get('Remote-User'):
-            request.remote_user = int(user_id)
+            request.remote_user = int(user_id) if user_id.isdigit() else None
         elif request.user.is_authenticated:
             request.remote_user = request.user.id
